
!----------------- BEGIN AccSqInt -----------------------------
      subroutine accsqint(acc, npts, dt, rmv_trnd, a_sq_int)


! Form integral of acceleration squared, assuming that the acceleration
! is represented by straight lines connecting the digitized values.  This
! routine can be used to compute Arias intensity, defined as

!            Ixx = (pi/2g)*int(acc^2*dt), integrating from 0.0 to the total
!  duration of the record.  The units of Ixx are 
!  velocity [ l^(-1)t^2*(l/t^2)^2*t ] =  l^(-1+2)*t^(2-4+1) = l*t^(-1) = l/t

! Be sure to use consistent units for the acceleration of gravity (g) and acc.
! I am not sure what is conventionally used, but Wilson (USGS OFR 93-556) 
! uses m/sec.

! Dates: 01/13/99 - Written by D.M. Boore
!        04/28/15 - Replaced comment characters * or C with ! (The Fortran 95 standard)

      real a_sq_int(*), acc(*)
      logical rmv_trnd
      double precision cum, a1, a2, ddt_3

      if (rmv_trnd) then      
! remove trend first
        call dcdt(acc, dt, npts, 1, npts, .false., .true.)
      end if

! compute integral of squared acceleration (assume a_sq_int = 0 for first point)

      ddt_3 = dble(dt/3)

      cum = 0.0

      a_sq_int(1) = sngl(cum)
      do j=2,npts
        a1 = acc(j-1)
        a2 = acc(j)
        cum = cum + (a1**2+a1*a2+a2**2)*ddt_3
        a_sq_int(j) = sngl(cum)
      end do

! high pass filter the velocity (may want to allow this in a future version;
! as it is, the acceleration time series can be filtered, so there is no need
! to do it again).

      return
      end
!----------------- END AccSqInt -----------------------------

