
!* ------------------------ BEGIN NOTCH ------------------------
      subroutine notch(s,nd,fr,delt,d,icaus)
c  notch filter (see Kanasewich, Time Sequence Analysis in 
c    Geophysics, Third Edition, University of Alberta Press, 
c    1981; Shanks, Feb. 1967 Geophysics)
c  written by W. B. Joyner 01/07/97
c  causal if icaus.eq.1 - zero phase shift otherwise
c  s(j) input = the time series to be filtered - output = the 
c    filtered series
c  dimension of s(j) must be at least as large as
c    nd+3.0*pi/d
c  nd = the number of points in the time series
c  fr = the reject frequency
c  delt = the timestep
c  d = parameter << 1 - the smaller d the narrower the notch - 
c    the value 0.01 is suggested for first trial
* Dates: 01/07/97 - Written by W. Joyner
*        07/20/01 - Option to return (no filtering) if fr < 0.0
!        03/20/10 - Tidied up by D. Boore

      real s(*)
      pi=4.0*atan(1.0)
      
      IF (fr < 0.0) THEN
        return
      END IF
      
      r = 1.0+d
      w = pi*fr*delt*2.0
      cosw = cos(w)
      fact = (1.0+2.0*cosw/r+1.0/r**2)/(2.0*(1.0+cosw))
      a1 = -2.0*cosw
      b1 = -2.0*cosw/r
      b2 = 1.0/r**2
      np2 = nd
      
      IF (icaus /= 1) THEN
      
        npad = 3.0*pi/d
        np1 = nd+1
        np2 = nd+npad
        
        DO j = np1, np2
          s(j) = 0.0
        END DO
        
      END IF
      
      x1 =0.0
      x2 =0.0
      y1 =0.0
      y2 =0.0
      
      DO j = 1, np2
      
        xp  = s(j)
        yp  = fact*(xp+a1*x1+x2)-b1*y1-b2*y2
        s(j) = yp
        y2 = y1
        y1 = yp
        x2 = x1
        x1 = xp
        
      END DO
      
      IF (icaus /= 1) THEN
      
        x1 = 0.0
        x2 = 0.0
        y1 = 0.0
        y2 = 0.0
        
        DO j = 1, np2 
        
          xp = s(np2-j+1)
          yp = fact*(xp+a1*x1+x2)-b1*y1-b2*y2
          s(np2-j+1) = yp
          y2 = y1
          y1 = yp
          x2 = x1
          x1 = xp
          
        END DO
        
      END IF
      
      RETURN
      
      END
!* ------------------------ END NOTCH ------------------------

