! ----------------------- BEGIN AmpPhPhD -------------------
      subroutine AmpPhPhD( data, dt, npw2,  
     :    amp, ph, phd, calc_phd, nsmooth_phd,
     :    apply_afact, df_fft, sign)

! Returns the amplitude, phase/twopi, and if calc_phd = .true., the derivative
! of phase with respect to angular frequency 
! (the derivative of phase with respect to frequency divided by twopi, so in 
! effect, both phase variables have been divided by twopi).

! Note that only the first npw2/2 points are returned (positive frequencies).
 
! I assume a plus sign in going from time to frequency

! Call subroutine CONDITION first to apply tapers, add zeros, etc, to data.

! apply_afact = .false. if data results from a call to FORK before
!                       calling ampphphd

! NOTE:  Must dimension the output arrays amp, ph, phd in the calling program

! Dates: 05/30/02 - Written by D. Boore, modified from Abs_Spect and using 
!                   Norm Abrahamson's code for computing phase derivatives.
!        06/20/02 - Allow data to be complex, so can compute the phase
!                   derivative of an analytical signal in order to
!                   obtain instantaneous frequency (see my phaseder.pdf)
!        06/25/02 - Added comment about lack of 2*pi in phd.
!        07/14/02 - Apply smoothing when computing phase difference
!                   (following Claerbout)
!        07/14/02 - removed "cmplx" in assigning cx_t
!        04/24/18 - Replace comment characters * and c with !


      real amp(*), ph(*), phd(*)
      complex data(*)
      real anumerator(:), adenominator(:)
      complex CX(:), CX_T(:)
      allocatable :: cx, cx_t, anumerator, adenominator
      logical calc_phd, apply_afact

      allocate( cx(npw2), cx_t(npw2), 
     :  anumerator(npw2), adenominator(npw2))

      pi = 4.0*atan(1.0)
      twopi = 2.0*pi

! sample rate and frequency spacing:

      sr = 1.0 / dt
      df_fft = sr/ float(npw2)

      if (apply_afact) then
        afact = dt*sqrt(float(npw2))
      else
        afact = 1.0
      end if

! Fill working complex array

      do i = 1, npw2
        cx(i)=data(i)
      end do

!     FFT to get spectrum

      call fork(npw2,cx,sign)


      do i = 1, npw2
        cx(i)=cx(i)*afact
        amp(i)=cabs( cx(i) )
        if (aimag(cx(i)) .eq. 0.0 .and. 
     :       real(cx(i)) .eq. 0.0)  then
          ph(i) = 0.0
        else
          ph(i) = atan2( aimag(cx(i)), real(cx(i)) )/twopi
        end if
      end do

      if (calc_phd ) then
        do i = 1, npw2
          cx_t(i)=float(i-1)*dt*data(i)
!          cx_t(i)=cmplx(float(i-1)*dt*data(i), 0.0)
        end do
        call fork(npw2,cx_t,sign)

        do i = 1, npw2
          cx_t(i)=cx_t(i)*afact

          anumerator(i) = 
     :       real(cx_t(i))*real(cx(i)) + aimag(cx_t(i))*aimag(cx(i))
          adenominator(i) = amp(i)**2

        end do
 
        call Smooth_N(anumerator,npw2,nsmooth_phd)
        call Smooth_N(adenominator,npw2,nsmooth_phd)

        do i = 1, npw2

          if (adenominator(i) .eq. 0.0) then
            phd(i) = -1.0e+08  ! set out of range
          else
            phd(i) = anumerator(i)/adenominator(i)
! Note: The definition of phd has a multiplicative factor of twopi, but
! the definitions of group delay and instantaneous frequency divide the 
! phase derivative by twopi.  For this reason, the twopi factors cancel and
! twopi has not been included in the computation of phd.  

          end if
        end do
      else
        do i = 1, npw2
          phd(i) = -1.0e+08  ! out of the range
        end do        
      end if

      deallocate( cx, cx_t, anumerator, adenominator)

      return
      end
! ----------------------- END AmpPhPhD -------------------

