! ----------------------- BEGIN Condition -------------------
      subroutine Condition(data, dt, npts, npw2, 
     :    frctnfrtaper, dc_remove, detrend, nzpad)

! The program applies a tapered window to the
! front and back of the time series, and pads with zeros if needed.

! The dynamic allocation of data must be done in the calling program, and
! must be large enough to allow for a zero pad.  I suggest including the
! following code in the calling program:

!      call get_npw2(npts,signnpw2,npw2)
!      n_alloc = max0(npw2, npts)
!      allocate( data(n_alloc))

! signnpw2 controls whether npw2 is less than npts (if signnpw2<0) or greater
! than npts, in which case zeros will be added in this subroutine.

! Base allocation on larger of npts or npw2, and use npw2 
! rather than npts in conditioning routines if npw2 < npts.

! I recommend detrend = .false.

! Dates: 05/30/02 - Written by D. Boore (modified from Abs_Spect)
!        04/24/18 - Replace comment characters * and c with !


      real DATA(*)
      logical dc_remove, detrend

      n_condition = min0(npw2, npts)

!
!     remove dc, apply taper, pad with zeros
!
      call dcdt(data, dt, n_condition, 1, n_condition, 
     : dc_remove, detrend)

      frctnfront = frctnfrtaper
      frctnback =  frctnfrtaper
      call tprfrctn (frctnfront, frctnback, data, n_condition)

      if (npw2 .gt. npts) then
        call zeropad( data, npts, npw2)
        nzpad = npw2 - npts
      else
        nzpad = 0
      end if

      return
      end
! ----------------------- END Conditn -------------------

