*----------------- BEGIN D2VA -----------------------------
      subroutine d2va(d, npts, dt, v, a)


* Compute acceleration and velocity from displacement, using the reverse process
* of going from acceleration to velocity,
* assuming that the acceleration
* is represented by straight lines connecting the digitized values.

* For consistency, I assume the v(1) and a(1) = 0.0, even if that is not
* true of v(1).

* But note this comment in acc2vd.for:
*        01/07/00 - Added initial velocity and displacements (v0, d0).
*                   This also requires the addition of a linear trend in
*                   displacement.
*                   Also, Bill Joyner, Chris Stephens, and I considered how to
*                   handle the first point.  Assuming v0 = 0, BAP uses a 
*                   trapezoidal rule such that the first vel(1) = 0.5*dt*a(1),
*                   but in acc2vd, vel(1) = 0.  In effect, BAP starts the
*                   integration at -dt rather than 0.0, with the result that
*                   because vel(1) depends on dt, vel(1) will change if the
*                   digitization interval is changed.  We agreed that this is 
*                   not correct.

* Dates: 10/20/02 - Written by D.M. Boore, patterned after v2a.for.

      real a(*), v(*), d(*)
      double precision v1, v2,
     : ddt_2


* compute velocity and displacement, using analytical formulas based
* on representing the acceleration as a series of straightline segments.

      ddt_2   = dble(dt/2)
      dtsq = dt*dt

      v(1) = 0.0 
      a(1) = 0.0 

      do j=2,npts
        dd = d(j) - d(j-1)
        da = 6.0*(dd/dt -v(j-1))/dt - 3.0*a(j-1)
        dv = (a(j-1) + da/2.0)*dt
        a(j) = a(j-1) + da
        v(j) = v(j-1) + dv
      end do

      return
      end
*----------------- END D2VA -----------------------------
