! ------------------------------------------------------------------ Get_Avg
      subroutine Get_Avg(a, 
     :  n_start, n_stop, npts, sps, icorr_cumavg, avg)

! Find mean of a between the two indices

! If itype = 1, then half weight is given to the first and last points
! (as it would be if computing velocity when the data before and after the
! indices are 0.0).

! Also consider (no confidence limits, however):

!      SUBROUTINE avg_std(data,n,avg,std,itype)
      
! Computes mean and standard deviation for an array of data.
! This is based on the Numerical Recipes program avevar.
! Itype specifies the type of mean:
! itype = 1: arithmetic mean, std = standard deviation
! itype = 2: geometric mean, std = factor by which mean is divided
!                                  and multiplied to yield the
!                                  equivalent of minus and plus
!                                  one standard deviation

! Or

!      subroutine mean_std_cl(a,npts,mean,std,seom,cl70,cl90,cl95,cl99)
! Computes mean, standard deviation, and confidence limits of the array entries





! Dates: 12/17/02 - Written by D. Boore
!        12/18/02 - Add icorr_cumavg to try to get program smc_pad to give 0.0
!                   velocity at the end of the data segment
!        12/18/02 - Rethinking computation of average when want to
!                   apply it to velocity case (looking at acc2vd.for algorithm)
!        05/01/15 - Replaced comment characters * or C with ! (The Fortran 95 standard)

      real a(*)
      real*8 cum_avg

      avg = 0.0
!      if (t4mean_start .lt. 0.0) t4mean_start = 0.0
!      if (t4mean_stop .gt. tend) t4mean_stop = tend
!      n_start = nint(sps * t4mean_start + 1.1)
!      n_stop = nint(sps * t4mean_stop + 1.1)
      if (n_start .lt. 0)    n_start = 1
      if (n_stop .gt. npts) n_stop = npts
      n_4mean = n_stop - n_start + 1
!      t4mean = float(n_4mean -1)/sps
      cum_avg = 0.0
      do i = n_start, n_stop
        cum_avg = cum_avg + dble(a(i))
      end do

      if (icorr_cumavg .eq. 1) then  ! Effectively ignore icorr_cumavg now
!        cum_avg = cum_avg - 0.5d00*(dble(a(n_start))+dble(a(n_stop)))         
!        avg = sngl(cum_avg/dble(float(n_4mean-1)))
        avg = sngl(cum_avg/dble(float(n_4mean)))
      else
        avg = sngl(cum_avg/dble(float(n_4mean)))
      end if

      return
      end
! ------------------------------------------------------------------ Get_Avg
