! begin subroutine interpolate_1d
      subroutine interpolate_1d(x, y, npts, ynull,
     :                          x_interp, y_interp)
      
! Returns y_interp = ynull if x_interp is outside of the range of x.
! The program assumes that x is ordered from small to large.
      
! Comments for locate:
!  finds j such that xx(j) < x <= xx(j+1)
!  EXCEPT if x = xx(1), then j = 1 (logically it would be 0 from
!  the above relation, but this is the same returned value of j
!  for a point out of range).
!  Also, if x = xx(n), j = n-1, which is OK
!  Note that j = 0 or j = n indicates that x is out of range.
!
! See the program test_locate.for to test the routine LOCATE.

! Dates: 05/27/10 - Written by D. Boore,
!                   using the equations in section 3.6 of 
!                   Press et al, Numerical Recipes (1992).

      real x(npts), y(npts), ynull,
     :     x_interp, y_interp, t, y1, y2
      
      integer j
      
      call locate(x,npts,x_interp,j)

      if (j == 0 .or. j == npts) then ! out of range
        y_interp = ynull
        return
      end if
      
      t = (x_interp - x(j))/(x(j+1) - x(j))
      
      y1 = y(j)
      y2 = y(j+1)
      
      y_interp = (1.0-t)*y1 + t*y2
      
      return
      end
! end subroutine interpolate_1d
 