! ----------------------------------------------------- interpolate_time_series_using_fork
      subroutine interpolate_time_series_using_fork(
     : y_in, sps_in, npts_in, 
     : interpolate_factor,
     : y_out, sps_out, npts_out
     : )


! Interpolates an smc file to finer spacing, using an FFT with zeroes
! added after the Nyquist.

! Dates: 09/29/12 - Written by D.M. Boore, patterned after smc_interpolate_time_series_using_fft.
!                 - This version does not allow for linear resampling after interpolation;
!                   for that, see smcintrp.for.
!                 - Return input time series if interpolate_factor = 1
!        02/09/18 - Redefine npts_out to be the length of y_out.
 
      implicit none

      real y_in(*), y_out(*) 
      integer npts_in, npts_out, npw2
      real sps_in, sps_out

      integer :: interpolate_factor, i, j, npw2_in, n4ts_alloc,
     :           n_nyq_in, npw2_intrp

      real(4) :: sps_intrp, scale, anorm, signnpw2, df 
      

 
!
! Dimension and declaration statements:

      complex cx_in(:), cx_intrp(:)
      allocatable :: cx_in, cx_intrp
 
      if (interpolate_factor == 1) then
        npts_out = npts_in
        sps_out = sps_in
        do i = 1, npts_out
          y_out(i) = y_in(i)
        end do
        return
      end if

! Check if interpolate_factor is a power of 2: 
       if (modulo(alog(real(interpolate_factor)), alog(2.0)) /= 0) then
         print *,' interpolate_factor= ', 
     :              interpolate_factor, ' not a power of 2; QUIT!!'
         stop
       end if
 
 
! Compute the Fourier spectra:

! Fill working array with input data:

      signnpw2 = +1.0
      call get_npw2(npts_in,signnpw2,npw2_in)
      
      n4ts_alloc = max0(npts_in, npw2_in)
      allocate( cx_in(npw2_in) )
 
      do i = 1, npw2_in
        cx_in(i) = 0.0
      end do

      do i = 1, npts_in
        cx_in(i) = cmplx(y_in(i), 0.0)
      end do

      df = sps_in/float(npw2_in)
      
      n_nyq_in = npw2_in/2 + 1

! FFT to get spectrum

!      call forkdp(npw2_in,cx_in,-1.)
      call fork(npw2_in,cx_in,-1.)

! Fill new complex array, inserting zeros

      npw2_intrp = npw2_in * interpolate_factor
      sps_intrp = sps_in * real(interpolate_factor)
      sps_out = sps_intrp
      scale = sps_intrp/sps_in
      anorm = sqrt(scale)
      npts_out =int( scale * float(npts_in) )
      
      
      allocate( cx_intrp(npw2_intrp) )
 
      do j = 1, npw2_intrp
        cx_intrp(j) = 0.0
      end do

      do j = 1, n_nyq_in
        cx_intrp(j)= cx_in(j)
      end do

      do j = 1, n_nyq_in - 2
        cx_intrp(npw2_intrp+1-j)= cx_in(npw2_in+1-j)
      end do

      deallocate( cx_in)

! Inverse FFT:

!      call forkdp(npw2_intrp,cx_intrp,+1.)
      call fork(npw2_intrp,cx_intrp,+1.)

! Scale for different lengths and save only the points up to the old last point:

      do j = 1, npts_out
        y_out(j) = anorm * real(cx_intrp(j))
      end do

      deallocate( cx_intrp)
      
  
      return
      end
! ----------------------------------------------------- interpolate_time_series_using_fork

 
