
* ------------------------------------------------------------------ Intrp_TS
      subroutine intrp_ts (t_in, y_in, n_in, sps, y_out, n_out,
     :                     ndimen_y_out)

* Linearly interpolate unevenly t_in, y_in to sps samples per second
* This program uses the following when t1 <> 0.0:

* NOTE: the program assumes that t_in is sorted in increasing order, without
*       duplicate values

c        When T1 >0.0: extrapolate along the line formed by the first
c        two input samples to get output samples before the first input
c        sample.
c        When T1 <0.0: In effect, throws away samples before 0.0 and
c        interpolates to get one at 0.0.

* Dates: 05/21/01 - Written by Dave Boore (a slightly modified version
*                   of April Converse's BAPSPS)
*        11/01/01 - Renamed the routine from ts_intrp to intrp_ts (easier
*                   for me to remember in the future).

      real t_in(*), y_in(*), y_out(*)

      double precision  time, timea, timeb, dpdt
 
c   Prepare for the interpolation loop.  At each step in the loop, we
c     will be interpolating between the two input samples at
c     (timea,ya) and (timeb,yb).
cc
      dpdt  = dble(1.0)/dble(sps)

      if (t_in(1) .gt. 0.0) then  ! construct an artificial initial value of
                                  ! y at t = 0.0
        timeb = 0.0d0
        timeb_a = t_in(2) - t_in(1)
        yb =  y_in(1) - (y_in(2)-y_in(1))*(t_in(1)/timeb_a)
        istart = 1
      else
        yb     = y_in(1)
        timeb = dble(t_in(1))
        istart = 2
      end if

      time  = 0.0d0
      n_out = 0

c   Loop over each point in the input series:
      do i = istart, n_in
         timea = timeb
         ya    = yb
         timeb = dble(t_in(i))
         yb    = y_in(i)

c   Loop over each output sample that lies between the current two
c     input samples.

         do while (time .ge. timea .and. time .lt. timeb)
            n_out = n_out + 1
            if (n_out .gt. ndimen_y_out) then
               n_out = n_out-1
               return
            endif
            y_out(n_out)
     :          =  ya + (yb-ya)*((time - timea)/(timeb-timea))
            time = dpdt*dble(n_out)
         end do  ! finish interpolating all output points between this pair
      end do ! end loop over input time series

      return

      end
* ------------------------------------------------------------------ Intrp_TS
