!----------------- BEGIN RDRVAA_RD_RV_TS -----------------------------
      subroutine rdrvaa_rd_rv_ts(acc,na,omega,damp,dt,rd,rv,aa,d0,v0,
     :                           ts_rd, ts_rv)
! This is a modified version of "Quake.For", originally
! written by J.M. Roesset in 1971 and modified by
! Stavros A. Anagnostopoulos, Oct. 1986.  The formulation is that of
! Nigam and Jennings (BSSA, v. 59, 909-922, 1969).  This modification
! returns the time series of the relative displacement, in addition to
! rd, rv, and aa

!   acc = acceleration time series
!    na = length of time series
! omega = 2*pi/per
!  damp = fractional damping (e.g., 0.05)
!    dt = time spacing of input
!    rd = relative displacement of oscillator
!    rv = relative velocity of oscillator
!    aa = absolute acceleration of oscillator
! d0,v0 = initial displacement and velocity (usually set to 0.0)

! Dates: 05/06/95 - Modified by David M. Boore
!        04/15/96 - Changed name to RD_CALC and added comment lines
!                   indicating changed for storing the oscillator time series
!                   and computing the relative velocity and absolute
!                   acceleration
!        04/16/96 - This is RD_CALC, with the time series of the relative
!                   displacement added and the name changed
!        03/14/01 - Made this double precision, but did not rename it as I
!                   did rc_calc and rdrvaa.  Also added initial displacement 
!                   and velocity.
!        01/31/03 - Moved implicit statement before the type declarations
!        10/10/07 - Initial variable assignments and iteration loop modified 
!                   to double-precision (Chris Stephens)
!        02/08/08 - Set ts(1)=0.0 and fill ts array up to na points.  The previous
!                   version of the program filled ts to na-1, but the program 
!                   calling this subroutine thought that the time series had
!                   a length of na.  What I do now is shift the ts by dt, assuming
!                   that ts(1) = 0.0
!        08/14/12 - Included 12/22/10 revision made to rscalc_ts: 
!                     Remove minus sign in front of the initialization of y, ydot. 
!                     The minus sign was a remnant of an earlier version where I did not
!                     understand the meaning of y and ydot.
!                 - Included 12/26/10 revision made to rscalc_ts: 
!                     Correct error that first vel and dis points = 0.0
!        09/22/12 - Renamed from rdcalcts, and now include rv and aa in output
!                   (following rdrvaa.for).
!        02/07/18 - Modified from rdrvaa_rd_ts.for, and nows writes out ts_rv, following rscalc_ts. 
!                   I am trying to decrease the number of programs that compute oscillator 
!                   response time series, as things have gotten quite confusing.  The
!                   program smc2psa_rot_gmrot_interp_acc_rot_osc_ts.for had used the
!                   subroutine rdrvaa_rd_ts, perhaps to avoid the extra time in computing
!                   ts_rv, but that extra cost is minor compared to the confusion of having
!                   too many programs that do almost the same thing.  So now 
!                   smc2psa_rot_gmrot_interp_acc_rot_osc_ts.for and smc2rs_ts.for will both
!                   call the subroutine rdrvaa_rd_rv_ts.  The subroutines rscalc_ts.for, rdcalcts.for, 
!                   and rdrvaa_rd_ts.for have all been saved with their latest dates as an extension,
!                   and the files with the actual names have been modified by deleting all
!                   content and adding the line
!                   ! Use rdrvaa_rd_rv_ts.for instead

!                   

      IMPLICIT REAL*8 (a-h,o-z)
      REAL*4 acc(*), omega, damp, dt, rd, rv, aa, d0, v0, 
     :       ts_rd(*), ts_rv(*)

      omt=dble(omega)*dble(dt)
      d2=1-dble(damp)*dble(damp)
      d2=dsqrt(d2)
      bom=dble(damp)*dble(omega)
      d3 = 2.*bom                 ! for aa
      omd=dble(omega)*d2
      om2=dble(omega)*dble(omega)
      omdt=omd*dble(dt)
      c1=1.d0/om2
      c2=2.d0*dble(damp)/(om2*omt)
      c3=c1+c2
      c4=1.d0/(dble(omega)*omt)
      ss=dsin(omdt)
      cc=dcos(omdt)
      bomt=dble(damp)*omt
      ee=dexp(-bomt)
      ss=ss*ee
      cc=cc*ee
      s1=ss/omd
      s2=s1*bom
      s3=s2+cc
      a11=s3
      a12=s1
      a21=-om2*s1
      a22=cc-s2
      s4=c4*(1.d0-s3)
      s5=s1*c4+c2
      b11=s3*c3-s5
      b12=-c2*s3+s5-c1
      b21=-s1+s4
      b22=-s4
      rd=0.
      rv = 0.                           ! for rv
      aa = 0.                           ! for aa

      y = dble(d0)
      ydot = dble(v0) ! These are initial values of the oscillator
!      y=0.
!      ydot=0.

      ts_rd(1) = d0  ! 14aug12
      ts_rv(1) = v0  ! 14aug12
!      ts(1) = 0.0  ! 08feb08

      DO i=1, na-1   ! 08feb08 (used new variable n1=na-1, but I replaced the upper limit with 
                     ! na-1 on 09/22/12, as n1 was only used here)

        y1=a11*y+a12*ydot+b11*dble(acc(i))+b12*dble(acc(i+1))
        ydot=a21*y+a22*ydot+b21*dble(acc(i))+b22*dble(acc(i+1))
        y=y1    ! y is the oscillator output at time corresponding to index i+1 
                ! changed "i" in this comment to "i+1" on 14aug12
        ts_rd(i+1) = y   !08feb08
        ts_rv(i+1) = ydot    
        z=dabs(y)
        if (z > rd) rd=z
        z1 = dabs(ydot)                   ! for rv
        if (z1 > rv) rv = z1            ! for rv
        ra = -d3*ydot -om2*y1            ! for aa
        z2 = dabs(ra)                     ! for aa
        if (z2 > aa) aa = z2            ! for aa

      END DO

      RETURN
      END
!----------------- END RDRVAA_RD_RV_TS -----------------------------

