! -------------------------- BEGIN SMOOTH_N --------------------------
      subroutine Smooth_N (y,npts,nsmooth)


! **** WARNING:  This is a non-maintained version; see SMOOTH_INTERPOLATE
! **** for the most recent code.

! Smooth y over nsmooth points (an odd number!) using
! a triangular weighting function.   Note that no attempt is made to 
! conserve array space: a working array is set up equal in size to the 
! input array. nsmooth = 1 implies no smoothing; array y is assumed to be 
! zero outside the range of values

! Note: nsmooth = 3 smooths with a 1/4,2/4,1/4 filter

! Note: if nsmooth is even, the program adds 1 to nsmooth

! Dates:  07/14/02 - Written by D. Boore
!        04/24/18 - Replace comment characters * and c with !

      real y(*)
      real work(:), weight(:)
      allocatable :: work, weight

      if (nsmooth .eq. 1) return

! Even?
      if (mod(nsmooth,2) .eq. 0) then
        nsmooth = nsmooth + 1
      end if      

      allocate(work(npts+nsmooth-1), weight(0:nsmooth+1) )

! Compute weights:
      do i = 0, nsmooth + 1
        weight(i) = 0.0
      end do

      nsmd2 = nsmooth/2
      do i = 1, nsmd2
        weight(i) = weight(i-1) + 1
        weight(nsmooth+1-i) = weight(nsmooth+1-i+1) + 1
      end do

      weight(nsmd2+1) = nsmd2+1

! Normalize:
      anorm = 0.0
      do i = 1, nsmooth
        anorm = anorm + weight(i)
      end do
      do i = 1, nsmooth
        weight(i) = weight(i)/anorm
      end do
        
! Apply weights (work is shifted to account for end regions):

      do i = 1, npts
        work(i+nsmd2) = y(i)
      end do
      do i = 1, nsmd2
        work(i) = 0.0
        work(npts+nsmooth-i) = 0.0
      end do

      do i = 1, npts
        accum = 0.0
        do j = 1, nsmooth      
          accum = accum + weight(j) * work(i+j-1)
        end do
        y(i) = accum
      end do
      
      deallocate(work, weight)

      return
      end
! -------------------------- END Smooth_N --------------------------
